onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() async {
super.onInit();
AppConfig.logger.t("Drawer Controller Init");
user = userServiceImpl?.user;
appProfile.value = userServiceImpl?.profile;
Sint.find<HomeService>().mediaPlayerEnabled = false;
if(user?.subscriptionId.isEmpty ?? true) initializeSubscriptionService();
}