BreathingCircleDelegate class
- Inheritance
-
- Object
- SplashAnimationDelegate
- BreathingCircleDelegate
Constructors
Properties
- cycleDuration → Duration
-
Duration of one animation cycle.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPainter(
{required double progress, required Color color, required Size size}) → CustomPainter -
Creates the CustomPainter for the current frame.
override
-
initialize(
Random random) → void -
Initialize animation data (particles, waves, etc.).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited