ProfileStatConfig class

Configuration for a single stat item in ProfileStatsCard.

Use this to define custom stats beyond the defaults:

ProfileStatsCard(
  profile: profile,
  customStats: [
    ProfileStatConfig(label: 'Casete', value: '1.2K', icon: Icons.headphones),
    ProfileStatConfig(label: 'Rating', value: '9.5', icon: Icons.star),
  ],
)

Constructors

ProfileStatConfig({required String label, required String value, int? numericValue, IconData? icon, VoidCallback? onTap, bool visible = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
label String
final
numericValue int?
Numeric value for animated count-up effect
final
onTap → VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited