SkeletonLoader class

Shimmer-effect skeleton loader for placeholder content.

Use this instead of CircularProgressIndicator for better UX during content loading. Supports various shapes and sizes.

Usage:

// Simple rectangle
SkeletonLoader(width: 200, height: 20)

// Circle (avatar placeholder)
SkeletonLoader.circle(radius: 30)

// Card placeholder
SkeletonLoader.card()

// Post grid placeholder
SkeletonLoader.postGrid(itemCount: 9)
Inheritance

Constructors

SkeletonLoader({double? width, double? height, double borderRadius = 4, bool isCircle = false, EdgeInsets? margin, Color? baseColor, Color? highlightColor, Key? key})
const
SkeletonLoader.circle({required double radius, EdgeInsets? margin, Color? baseColor, Color? highlightColor, Key? key})
Creates a circular skeleton (for avatars)
const
SkeletonLoader.text({double width = double.infinity, double height = 14, EdgeInsets? margin, Key? key})
Creates a text line skeleton
factory

Properties

baseColor → Color?
final
borderRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
highlightColor → Color?
final
isCircle → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SkeletonLoader>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited