SliderModel class

Constructors

SliderModel(String imagePath, String title, String msg1, {String msg2 = ""})

Properties

hashCode → int
The hash code for this object.
no setterinherited
imagePath ↔ String
getter/setter pair
msg1 ↔ String
getter/setter pair
msg2 ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited