WebBreakpoints class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

gridColumns(double width, {int mobileColumns = 2, int tabletColumns = 3, int desktopColumns = 4, int wideDesktopColumns = 5}) → int
isDesktop(double width) → bool
isMobile(double width) → bool
isTablet(double width) → bool
isWideDesktop(double width) → bool
showRightPanel(double width) → bool
sidebarExpanded(double width) → bool
sidebarWidth(double width) → double

Constants

desktop → const double
mobile → const double
smallDesktop → const double
tablet → const double