CommandPaletteItem class

A single command entry in the palette.

Constructors

CommandPaletteItem({required String id, required String label, required String section, required IconData icon, required VoidCallback onSelect, List<String> keywords = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
id String
final
keywords List<String>
final
label String
final
onSelect → VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
section String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited