WebTableColumn<T> class
Constructors
- WebTableColumn({required String label, double? width, required Widget cellBuilder(T item), Comparable sortKey(T item)?})
-
const
Properties
- cellBuilder → Widget Function(T item)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortKey → Comparable Function(T item)?
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited