WebShortcutEntry class

Data class describing a registered shortcut for help display.

Constructors

WebShortcutEntry({required List<String> keyLabels, required String description, required String category})
const

Properties

category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
keyLabels List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited