WebThemeConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- glassCard → BoxDecoration
-
no setter
- panelDecoration → BoxDecoration
-
no setter
-
no setter
Static Methods
-
fadeSwitch(
Widget child, {Key? key}) → Widget
Constants
- hoverDuration → const Duration
- transitionDuration → const Duration