canModerate static method
Returns true if the given role has moderation privileges (editor+).
Implementation
static bool canModerate(UserRole role) {
return role.value >= UserRole.editor.value;
}
Returns true if the given role has moderation privileges (editor+).
static bool canModerate(UserRole role) {
return role.value >= UserRole.editor.value;
}