DeeplinkUtilities class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleDeepLink(
Uri uri) → void -
initDeepLinks(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateDeepLink(
{required String host, required String type, required String id}) → String - @deprecated Use generateVanityUrl instead.
-
generateVanityUrl(
{required String type, String id = '', String slug = ''}) → String - Generates a vanity URL for sharing. Examples:
- Navigates to content with home/root behind in the navigation stack. Clears the stack → root, waits a frame, then pushes the content route. Pressing "back" from the content returns to home.