AppDrawerMenu enum
Values
- profile → const AppDrawerMenu
-
const AppDrawerMenu("profile") - frequencies → const AppDrawerMenu
-
const AppDrawerMenu("frequencies") - presets → const AppDrawerMenu
-
const AppDrawerMenu("presets") - instruments → const AppDrawerMenu
-
const AppDrawerMenu("instruments") - genres → const AppDrawerMenu
-
const AppDrawerMenu("genres") - digitalLibrary → const AppDrawerMenu
-
const AppDrawerMenu("digitalLibrary") - collectives → const AppDrawerMenu
-
const AppDrawerMenu("collectives") - events → const AppDrawerMenu
-
const AppDrawerMenu("events") - inbox → const AppDrawerMenu
-
const AppDrawerMenu("inbox") - calendar → const AppDrawerMenu
-
const AppDrawerMenu("calendar") - services → const AppDrawerMenu
-
const AppDrawerMenu("services") - requests → const AppDrawerMenu
-
const AppDrawerMenu("requests") - booking → const AppDrawerMenu
-
const AppDrawerMenu("booking") - directory → const AppDrawerMenu
-
const AppDrawerMenu("directory") - settings → const AppDrawerMenu
-
DEPRECATED wallet("wallet"),
const AppDrawerMenu("settings") - appItemQuotation → const AppDrawerMenu
-
const AppDrawerMenu("appItemQuotation") - crowdfunding → const AppDrawerMenu
-
const AppDrawerMenu("crowdfunding") - logout → const AppDrawerMenu
-
const AppDrawerMenu("logout") - releaseUpload → const AppDrawerMenu
-
const AppDrawerMenu("releaseUpload") - inspiration → const AppDrawerMenu
-
const AppDrawerMenu("inspiration") - games → const AppDrawerMenu
-
DEPRECATED nupale("nupale"), DEPRECATED casete("casete"),
const AppDrawerMenu("games") - learning → const AppDrawerMenu
-
const AppDrawerMenu("learning") - vst → const AppDrawerMenu
-
const AppDrawerMenu("vst") - daw → const AppDrawerMenu
-
const AppDrawerMenu("daw") - erp → const AppDrawerMenu
-
const AppDrawerMenu("erp") - dashboard → const AppDrawerMenu
-
const AppDrawerMenu("dashboard")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AppDrawerMenu> - A constant List of the values in this enum, in order of their declaration.