BaseItemMapper class

Constructors

BaseItemMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromAppMediaItem(AppMediaItem mediaItem) → BaseItem
fromAppReleaseItem(AppReleaseItem releaseItem) → BaseItem
fromChamberPreset(NeomChamberPreset chamberPreset) → BaseItem
fromDynamicItem(dynamic item) → BaseItem
fromExternalItem(ExternalItem externalItem) → BaseItem
fromPlayableItem(PlayableItem item) → BaseItem
Converts any PlayableItem to BaseItem using the interface fields.