ShareUtilities class

Constructors

ShareUtilities()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

shareApp() Future<void>
shareAppWithMediaItem(AppMediaItem mediaItem) Future<void>
shareAppWithPost(Post post) Future<void>
shareBlogEntry(BlogEntry blogEntry) Future<void>
Share a BlogEntry with optional thumbnail.
shareEvent(Event event) Future<void>
Share an Event with date, place, and vanity URL.
shareProduct({required String productId, required String name, required String imgUrl, required double price, required String ownerName, String type = 'product'}) Future<void>
Share a shop product (AppReleaseItem or ShopMerchItem) with vanity URL.