getAudioSearchHint static method
Returns the search bar hint text for the audio player, customized per app. Each app has content aligned with its brand identity.
Implementation
static String getAudioSearchHint() {
switch (AppConfig.instance.appInUse) {
case AppInUse.g:
return AppTranslationConstants.searchHintGigmeout.tr;
case AppInUse.e:
return AppTranslationConstants.searchHintEmxi.tr;
case AppInUse.c:
return AppTranslationConstants.searchHintCyberneom.tr;
default:
return AppTranslationConstants.searchHintDefault.tr;
}
}