WebContentWrapper class
Wraps content with max-width constraints and centering on web/wide screens. On mobile (narrow screens), returns the child unmodified.
Usage:
// Basic — wraps body Container in Scaffold
body: WebContentWrapper(
maxWidth: 800,
padding: EdgeInsets.zero,
child: Container(
decoration: AppTheme.appBoxDecoration,
child: ListView(...),
),
),
// With back button (for pages without AppBar)
body: WebContentWrapper(
maxWidth: 800,
showBackButton: true,
child: SingleChildScrollView(...),
),
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- WebContentWrapper
Constructors
- WebContentWrapper({required Widget child, double maxWidth = 680, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16), bool showBackButton = false, Key? key})
-
const
Properties
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxWidth → double
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBackButton → bool
-
Shows a back button at the top-left on web.
Use for pages that don't have an AppBar.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited