WebShortcutEntry class
Data class describing a registered shortcut for help display.
Constructors
-
WebShortcutEntry({required List<
String> keyLabels, required String description, required String category}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited